#region Copyright Syncfusion Inc. 2001 - 2017
// Copyright Syncfusion Inc. 2001 - 2017. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.EJ.Export;
using Syncfusion.JavaScript.Models;
using Syncfusion.XlsIO;
using System.Collections.Specialized;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.ServiceModel;
using System.ServiceModel.Web;
using System.Text;
using System.Web;
using System.Web.Http;

namespace SpreadsheetSample
{
    /// <summary>
    /// Used to Import and export data from Spreadsheet component
    /// </summary>
    [ServiceContract(Namespace = "")]
    [XmlSerializerFormat]
    public class SpreadSheetController : ApiController
    {

        [AcceptVerbs("Post")]
        public void ExcelExport()
        {
            string sheetModel = HttpContext.Current.Request.Params["sheetModel"], sheetData = HttpContext.Current.Request.Params["sheetData"], password = HttpContext.Current.Request.Params["password"];
            if (!string.IsNullOrEmpty(password))
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013, password);
            else
                Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.XLSX, ExcelVersion.Excel2013);
        }


        [AcceptVerbs("Post")]
        public void CsvExport()
        {
            string sheetModel = HttpContext.Current.Request.Params["sheetModel"], sheetData = HttpContext.Current.Request.Params["sheetData"];
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.CSV);
        }


        [AcceptVerbs("Post")]
        public void PdfExport()
        {
            string sheetModel = HttpContext.Current.Request.Params["sheetModel"], sheetData = HttpContext.Current.Request.Params["sheetData"];
            Spreadsheet.Save(sheetModel, sheetData, "sample", ExportFormat.PDF);
        }

        [AcceptVerbs("Post")]
        [OperationContract]
        [WebGet(BodyStyle = WebMessageBodyStyle.Bare)]
        public HttpResponseMessage Import()
        {
            string password = "password", sheetIndex = "sheetIndex", dataContainer = "dataContainer", allowSheetOnDemand = "allowSheetOnDemand";
            bool isImport = true;
            Stream fileStream = null;
            var files = HttpContext.Current.Request.Files;
            NameValueCollection form = HttpContext.Current.Request.Form;
            ImportRequest importRequest = new ImportRequest();
            if (files.Count == 0)
            {
                if (string.IsNullOrEmpty(form["url"]))
                {
                    string filePath = HttpContext.Current.Server.MapPath("~/Files/TestFile.xlsx");
                    fileStream = File.Open(filePath, FileMode.Open, FileAccess.Read);
                    importRequest.FileStream = fileStream;
                }
                else
                    importRequest.Url = form["url"];
            }
            else
            {
                var obj = files[0];
                if (obj.ContentType.IndexOf("image") > -1)
                {
                    importRequest.File = new HttpPostedFileWrapper(files[0]);
                    isImport = false;
                }
                else
                {
                    importRequest.FileStream = obj.InputStream;
                    importRequest.FileType = obj.FileName.Split('.')[obj.FileName.Split('.').Length - 1];
                    importRequest.File = null;
                }
            }
            if (isImport)
            {
                string[] keys = form.AllKeys;
                if (keys.Contains(password))
                    importRequest.Password = form[password];
                if (keys.Contains(allowSheetOnDemand))
                    importRequest.AllowSheetOnDemand = bool.Parse(form[allowSheetOnDemand]);
                if (keys.Contains(sheetIndex))
                    importRequest.SheetIndex = int.Parse(form[sheetIndex]);
                if (keys.Contains(dataContainer))
                    importRequest.DataContainer = form.GetValues(dataContainer);
            }
            string str = Spreadsheet.Open(importRequest);
            if (fileStream != null)
                fileStream.Close();
            return new HttpResponseMessage() { Content = new StringContent(str, Encoding.UTF8, "text/plain") };
        }
    }
}
